@@ -2,6 +2,6 @@
 
 __author__ = """Sarah Bird"""
 __email__ = 'sbird@mozilla.com'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
-from .domain_utils import *
+from .domain_utils import *  # noqa
